@@ -694,7 +694,7 @@ class BaseSystem(object):
         Util.appendOrReplaceInFile(filename, search, replace)
 
     def configureCloudProxyService(self):
-        self.installPackages(['stratuslab-one-proxy'])
+        self.installPackages(['stratuslab-one-proxy', 'stratuslab-nginx-load'])
         self._configureProxyDefaultUsers()
         self._restartJetty()
 
@@ -1151,7 +1151,7 @@ group {
         rc = self.restartService(serviceName)
 
         if rc != 0:
-            Util.printError('Filed to (re)start DHCP service.')
+            Util.printError('Failed to (re)start DHCP service.')
 
     # -------------------------------------------
     # DB
