@@ -51,8 +51,9 @@ class Runner(VmManager):
   TYPE=fs ]'''
 
     # Don't hard code disk target to allow multiple pdisk attachment
+    # NOTE: The pdiskEndpoint must NOT have a trailing slash.
     PERSISTENT_DISK = '''DISK=[
-  SOURCE=pdisk:%(pdiskEndpointHostname)s:%(pdiskPort)s:%(persistentDiskUUID)s,
+  SOURCE=pdisk:%(pdiskEndpoint)s/%(persistentDiskUUID)s,
   TARGET=%(vm_disks_prefix)sc,
   TYPE=block ]'''
 
@@ -97,7 +98,7 @@ class Runner(VmManager):
         self.rawData = ''
         self.extraContextFile = ''
         self.extraContextData = ''
-        self.cloudInit = ''
+        self.cloudInit = None
         self.vncPort = ''
         self.vncListen = ''
         self.noCheckImageUrl = False
@@ -227,7 +228,12 @@ class Runner(VmManager):
             return
 
         self.pdiskEndpointHostname = VolumeManager.getFQNHostname(self.pdiskEndpoint)
-        self.persistent_disk = (self.persistentDiskUUID and Runner.PERSISTENT_DISK % self.__dict__) or ''
+
+        # Ensure that the pdiskEndpoint does not have a trailing slash.
+        opts = self.__dict__.copy()
+        opts['pdiskEndpoint'] = self.pdiskEndpoint.rstrip('/')
+
+        self.persistent_disk = (self.persistentDiskUUID and Runner.PERSISTENT_DISK % opts) or ''
 
         self._checkPersistentDiskAvailable()
 
@@ -308,7 +314,7 @@ class Runner(VmManager):
                      'isPrivateIp': False,
                      'extraContextFile': '',
                      'extraContextData': '',
-                     'cloudInit': '',
+                     'cloudInit': None,
                      # FIXME: hack to fix a weird problem with network in CentOS on Fedora 14 + KVM.
                      #        Network is not starting unless VNC is defined. Weird yeh...? 8-/
                      'vncPort': '-1',
@@ -445,9 +451,14 @@ class Runner(VmManager):
         if self.extraContextData:
             contextElems.extend(self.extraContextData.split(Util.cliLineSplitChar))
 
-        if self.cloudInit:
+        if self.cloudInit or (hasattr(self, 'defaultContextMethod') and 
+                              self.defaultContextMethod and 
+                              self.defaultContextMethod == 'cloud-init'):
+            if self.cloudInit is None:
+                self.cloudInit = ''
+
             cloudInitArgs = self.cloudInit.split(Util.cliLineSplitChar)
-            cloudInitData = CloudInitUtil.contextFile(cloudInitArgs)
+            cloudInitData = CloudInitUtil.context_file(cloudInitArgs, default_public_key_file=self.userPublicKeyFile)
             contextElems.extend(cloudInitData.split('\n'))
 
         for line in contextElems:
@@ -615,7 +626,7 @@ class Runner(VmManager):
     def _createDiskUrlIfDiskId(self, image):
         if Image.isDiskId(image):
             self.pdiskEndpointHostname = VolumeManager.getFQNHostname(self.pdiskEndpoint)
-            return "pdisk:%s:%s:%s" % (self.pdiskEndpointHostname, self.pdiskPort, image)
+            return "pdisk:%s/%s" % (self.pdiskEndpoint.rstrip('/'), image)
         else:
             return image
 
